==> currents-api-types-0.0.35.tgz: package/payin/types.ts <==
import { StripePaymentIntentId } from '../stripe/types';
import { ORIGIN_TYPE_PAYPAL, ORIGIN_TYPE_STRIPE, ORIGIN_TYPES_EXTERNAL } from '../origin/constants';
import { Subset } from '../utils/types';
import { PAYIN_CHANNEL_API_LITERAL_TYPE, PAYIN_USER_API_LITERAL_TYPE } from './constants';
import {
  payinApiDstCompositeParser,
  payinApiSrcCompositeParser,
  payinApiSrcDstCompositeParserOptional,
  SEPARATOR,
} from './parsers';
import { UserId } from '../user/types';
import { ChannelIdOfType, ChannelType } from '../channel/types';
import z from 'zod';
import { TipStatus } from '../tip/types';
import { SubscriptionStatus } from '../subscription/types';

export type PayinOriginType = typeof ORIGIN_TYPES_EXTERNAL[number];
export type TipOriginId = StripePaymentIntentId;
export type SubscriptionPaymentOriginId = StripePaymentIntentId;
export type PayinOriginIdMapping = {
  [ORIGIN_TYPE_STRIPE]: TipOriginId | SubscriptionPaymentOriginId;
  [ORIGIN_TYPE_PAYPAL]: string;
};
// eslint-disable-next-line
type AssertPayinOriginIdMapping = Subset<
  PayinOriginIdMapping,
  {
    [k in PayinOriginType]: unknown;
  }
>;
export type PayinOriginId<T extends PayinOriginType = PayinOriginType> = PayinOriginIdMapping[T];
export enum PayinSrcBrand {
  _ = '',
}
export type PayinSrc = `${typeof PAYIN_USER_API_LITERAL_TYPE}${typeof SEPARATOR}${UserId}` & PayinSrcBrand;
export enum PayinDstBrand {
  _ = '',
}
export type PayinDst<T extends ChannelType = ChannelType> =
  `${typeof PAYIN_CHANNEL_API_LITERAL_TYPE}${typeof SEPARATOR}${ChannelIdOfType<T>}` & PayinDstBrand;
export type ApiPayinSrcComposite = z.infer<typeof payinApiSrcCompositeParser>;
export type ApiPayinDstComposite = z.infer<typeof payinApiDstCompositeParser>;

// frontend currently handles both tip and subscription creations the same way, expecting the same shape
// these are the fields that are common to both and used by the frontend
export type ApiPayinResultMixin<T extends 'tip' | 'subscription'> = {
  // a secret to follow thru with subscription payment process; user in Stripe; TODO move out of this type
  client_secret?: string;
  status: T extends 'tip' ? TipStatus : T extends 'subscription' ? SubscriptionStatus : never;
};

export type PayinSrcDstApiQueryMixin = z.infer<typeof payinApiSrcDstCompositeParserOptional>;

==> currents-api-types-0.0.40.tgz: package/payin/types.ts <==
import { StripePaymentIntentId } from '../stripe/types';
import { ORIGIN_TYPE_PAYPAL, ORIGIN_TYPE_STRIPE, ORIGIN_TYPES_EXTERNAL } from '../origin/constants';
import { Subset } from '../utils/types';
import { PAYIN_CHANNEL_API_LITERAL_TYPE, PAYIN_USER_API_LITERAL_TYPE } from './constants';
import {
  payinApiDstCompositeParser,
  payinApiSrcCompositeParser,
  payinApiSrcDstCompositeParserOptional,
  rerunImpossiblePaymentIntentParamsParser,
  SEPARATOR,
} from './parsers';
import { UserId } from '../user/types';
import { ChannelIdOfType, ChannelType } from '../channel/types';
import z from 'zod';
import { TipStatus } from '../tip/types';
import { SubscriptionStatus } from '../subscription/types';

export type PayinOriginType = typeof ORIGIN_TYPES_EXTERNAL[number];
export type TipOriginId = StripePaymentIntentId;
export type SubscriptionPaymentOriginId = StripePaymentIntentId;
export type PayinOriginIdMapping = {
  [ORIGIN_TYPE_STRIPE]: TipOriginId | SubscriptionPaymentOriginId;
  [ORIGIN_TYPE_PAYPAL]: string;
};
// eslint-disable-next-line
type AssertPayinOriginIdMapping = Subset<
  PayinOriginIdMapping,
  {
    [k in PayinOriginType]: unknown;
  }
>;
export type PayinOriginId<T extends PayinOriginType = PayinOriginType> = PayinOriginIdMapping[T];
export enum PayinSrcBrand {
  _ = '',
}
export type PayinSrc = `${typeof PAYIN_USER_API_LITERAL_TYPE}${typeof SEPARATOR}${UserId}`; // & PayinSrcBrand makes the type never??
export enum PayinDstBrand {
  _ = '',
}
export type PayinDst<T extends ChannelType = ChannelType> =
  `${typeof PAYIN_CHANNEL_API_LITERAL_TYPE}${typeof SEPARATOR}${ChannelIdOfType<T>}` & PayinDstBrand;
export type ApiPayinSrcComposite = z.infer<typeof payinApiSrcCompositeParser>;
export type ApiPayinDstComposite = z.infer<typeof payinApiDstCompositeParser>;

// frontend currently handles both tip and subscription creations the same way, expecting the same shape
// these are the fields that are common to both and used by the frontend
export type ApiPayinResultMixin<T extends 'tip' | 'subscription'> = {
  // a secret to follow thru with subscription payment process; user in Stripe; TODO move out of this type
  client_secret?: string;
  status: T extends 'tip' ? TipStatus : T extends 'subscription' ? SubscriptionStatus : never;
};

export type PayinSrcDstApiQueryMixin = z.infer<typeof payinApiSrcDstCompositeParserOptional>;

export type RerunImpossiblePaymentIntentParams = z.infer<typeof rerunImpossiblePaymentIntentParamsParser>;
